Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2021-10-21 05:24:17 +0300
committerCampbell Barton <ideasman42@gmail.com>2021-10-21 05:24:17 +0300
commit035dcdad90ec9d6881e2d99b90e30f5a481237e1 (patch)
treef4b0c0bf97fee7ed9813f9b5587b03af180251e9 /source/blender/windowmanager/WM_types.h
parent69102786047dccdcbaee0df6307a8c3364d28fe0 (diff)
Cleanup: use underscore separators for event struct members
Improve readability using underscores for separators, e.g. prev_click_time instead of prevclicktime.
Diffstat (limited to 'source/blender/windowmanager/WM_types.h')
-rw-r--r--source/blender/windowmanager/WM_types.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/windowmanager/WM_types.h b/source/blender/windowmanager/WM_types.h
index 105e533ad22..f4595869baf 100644
--- a/source/blender/windowmanager/WM_types.h
+++ b/source/blender/windowmanager/WM_types.h
@@ -600,7 +600,7 @@ typedef struct wmTabletData {
* - Previous x/y are exceptions: #wmEvent.prev
* these are set on mouse motion, see #MOUSEMOVE & track-pad events.
*
* - Modal key-map handling sets `prevval` & `prevtype` to `val` & `type`,
* this allows modal keys-maps to check the original values (needed in some cases).
*/
typedef struct wmEvent {
@@ -632,17 +632,17 @@ typedef struct wmEvent {
char is_repeat;
/** The previous value of `type`. */
- short prevtype;
+ short prev_type;
/** The previous value of `val`. */
- short prevval;
+ short prev_val;
/** The time when the key is pressed, see #PIL_check_seconds_timer. */
- double prevclicktime;
+ double prev_click_time;
/** The location when the key is pressed (used to enforce drag thresholds). */
int prev_click_xy[2];
/**
* The previous value of #wmEvent.xy,
* Unlike other previous state variables, this is set on any mouse motion.
* Use `prevclick` for the value at time of pressing.
*/
int prev_xy[2];
@@ -658,7 +658,7 @@ typedef struct wmEvent {
/* Custom data. */
/** Custom data type, stylus, 6dof, see wm_event_types.h */
short custom;
- short customdatafree;
+ short customdata_free;
int pad2;
/** Ascii, unicode, mouse-coords, angles, vectors, NDOF data, drag-drop info. */
void *customdata;
@@ -600,7 +600,7 @@ typedef struct wmTabletData {
* these are set on mouse motion, see #MOUSEMOVE & track-pad events.
*
- * - Modal key-map handling sets `prevval` & `prevtype` to `val` & `type`,
+ * - Modal key-map handling sets `prev_val` & `prev_type` to `val` & `type`,
* this allows modal keys-maps to check the original values (needed in some cases).
*/
@@ -632,17 +632,17 @@ typedef struct wmEvent {
* The previous value of #wmEvent.xy,
* Unlike other previous state variables, this is set on any mouse motion.
- * Use `prevclick` for the value at time of pressing.
+ * Use `prev_click` for the value at time of pressing.
*/
int prev_xy[2];